pub enum Backpressure {
Park,
Drop,
}Expand description
Backpressure policy for writers when the buffer is full.
Variants
Park
Writers park (Pending) until space is available.
Drop
Writers drop data when no space is available (return Ok(0)).