pub enum Reader {
Strong(StrongReader),
Weak(WeakReader),
}Expand description
Convenience type for implementors to treat both reader types as one.
Variants
Strong(StrongReader)
Strong reader variant that maintains backpressure guarantees.
Weak(WeakReader)
Weak reader variant that may drop data when lagging.
Implementations
Sourceimpl Reader
impl Reader
Sourcepub fn into_strong(self) -> Result<StrongReader, Self>
pub fn into_strong(self) -> Result<StrongReader, Self>
Extract the strong reader variant, returning self on mismatch.
Sourcepub fn into_weak(self) -> Result<WeakReader, Self>
pub fn into_weak(self) -> Result<WeakReader, Self>
Extract the weak reader variant, returning self on mismatch.