pub struct StrongReader { /* private fields */ }Expand description
Reader that prevents overwriting unread bytes.
Implementations
Sourceimpl StrongReader
impl StrongReader
Sourcepub fn terminate(&self)
pub fn terminate(&self)
Safely terminate this reader.
This will cause poll_read to error with std::io::ErrorKind::ConnectionAborted.
Sourcepub async fn read_frame(&mut self, max_len: usize) -> Result<(u16, Vec<u8>)>
pub async fn read_frame(&mut self, max_len: usize) -> Result<(u16, Vec<u8>)>
Read a complete frame, returning the writer identifier and payload bytes.
Sourcepub fn downgrade(self) -> WeakReader
pub fn downgrade(self) -> WeakReader
Convert this strong reader into a weak reader that relinquishes its head slot when idle.