pub struct StrongWriter { /* private fields */ }Expand description
Writer that maintains a persistent tail slot and participates in backpressure accounting.
Implementations
Sourceimpl StrongWriter
impl StrongWriter
Sourcepub fn writable_size(&self) -> u64
pub fn writable_size(&self) -> u64
Current number of bytes the writer can append without blocking.
Sourcepub fn terminate(&mut self)
pub fn terminate(&mut self)
Safely terminate this writer.
This will cause poll_write to error with std::io::ErrorKind::ConnectionAborted.
Sourcepub fn downgrade(self) -> WeakWriter
pub fn downgrade(self) -> WeakWriter
Convert this strong writer into a weak writer that relinquishes its tail slot when idle.